Struct GlyphMetrics
pub struct GlyphMetrics<'a> { /* private fields */ }Expand description
Glyph specific metrics.
Implementations
impl<'a> GlyphMetrics<'a>
impl<'a> GlyphMetrics<'a>
pub fn new(
font: &FontRef<'a>,
size: Size,
location: impl Into<LocationRef<'a>>,
) -> GlyphMetrics<'a>
pub fn new( font: &FontRef<'a>, size: Size, location: impl Into<LocationRef<'a>>, ) -> GlyphMetrics<'a>
Creates new glyph metrics from the given font, size, and location in normalized variation space.
pub fn glyph_count(&self) -> u32
pub fn glyph_count(&self) -> u32
Returns the number of available glyphs in the font.
pub fn advance_width(&self, glyph_id: GlyphId) -> Option<f32>
pub fn advance_width(&self, glyph_id: GlyphId) -> Option<f32>
Returns the advance width for the specified glyph.
If normalized coordinates were provided when constructing glyph metrics and
an HVAR table is present, applies the appropriate delta.
Returns None if glyph_id >= self.glyph_count() or the underlying font
data is invalid.
pub fn left_side_bearing(&self, glyph_id: GlyphId) -> Option<f32>
pub fn left_side_bearing(&self, glyph_id: GlyphId) -> Option<f32>
Returns the left side bearing for the specified glyph.
If normalized coordinates were provided when constructing glyph metrics and
an HVAR table is present, applies the appropriate delta.
Returns None if glyph_id >= self.glyph_count() or the underlying font
data is invalid.
pub fn bounds(&self, glyph_id: GlyphId) -> Option<BoundingBox<f32>>
pub fn bounds(&self, glyph_id: GlyphId) -> Option<BoundingBox<f32>>
Returns the bounding box for the specified glyph.
Returns None if glyph_id >= self.glyph_count(), the underlying font
data is invalid.